@@ -1,9 +1,10 @@
 use v5.24;
 
 package Dist::Zilla::Plugin::LocalHTML::Pod2HTML;
+
 # ABSTRACT: Pod::Simple::HTML wrapper to generate local links for project modules.
 
-our $VERSION = 'v0.1.0';
+our $VERSION = 'v0.1.1';
 
 use File::Spec;
 use Data::Dumper;
@@ -14,41 +15,93 @@ use MooseX::NonMoose;
 use namespace::autoclean;
 extends qw<Pod::Simple::HTML>;
 
+
 has callerPlugin => (
     is      => 'ro',
     isa     => 'Dist::Zilla::Plugin::LocalHTML',
     handles => [qw<log log_debug>],
 );
 
+
 has prefixRx => (
     is      => 'ro',
     lazy    => 1,
     builder => 'init_prefixRx',
 );
 
+has local_files => (
+    is      => 'ro',
+    lazy    => 1,
+    clearer => 'clear_local_files',
+    builder => 'init_local_files',
+);
+
+
+sub _mod2file {
+    my $this = shift;
+    my $mod  = shift;
+    my $file = File::Spec->catfile( split /::/, $mod );
+    return $this->callerPlugin->base_filename($file);
+}
+
 around do_pod_link => sub {
     my $orig   = shift;
     my $this   = shift;
     my ($link) = @_;
 
-    $this->log_debug( "do_pod_link:", Dumper($link) );
-
-    if ( $link->tagname eq 'L' and $link->attr('type') eq 'pod' ) {
-        my $lpRx = $this->prefixRx;
-        my $to   = "" . $link->attr('to');
-        if ( $to =~ /^$lpRx/n ) {
-            my $toFile = File::Spec->catfile(split /::/, $to);
-            my $ref = $this->callerPlugin->base_filename($toFile);
-            $this->log_debug("Resulting link:", $ref);
+    if (   ( $link->tagname eq 'L' )
+        && ( $link->attr('type') eq 'pod' ) )
+    {
+        my $ref = "";
+        if ( $link->attr('to') ) {
+            my $lpRx   = $this->prefixRx;
+            my $to     = "" . $link->attr('to');
+            my $toFile = $this->_mod2file($to);
+            if ( ( defined($lpRx) && $to =~ /^$lpRx/n )
+                || $this->local_files->{$toFile} )
+            {
+                # Local link
+                $ref .= $toFile;
+            }
+            else {
+                # External link. Override default generator because
+                # search.cpan.org seems to be down as for now.
+                $ref .= "https://metacpan.org/pod/$to";
+            }
+        }
+        if ( $link->attr('section') ) {
+            my $section = "" . $link->attr('section');
+            $ref .= "#" . $this->section_escape($section);
+        }
+        if ($ref) {
+            $this->log_debug( "Resulting link:", $ref );
             return $ref;
         }
     }
+
+    return $orig->( $this, @_ );
 };
 
+
 sub init_prefixRx {
+    my $this   = shift;
+    my @pfList = @{ $this->callerPlugin->local_prefix };
+    return @pfList
+      ? "(?<prefix>" . join( "|", @pfList ) . ")"
+      : undef;
+}
+
+sub init_local_files {
     my $this = shift;
-    return
-      "(?<prefix>" . join( "|", @{ $this->callerPlugin->local_prefix } ) . ")";
+
+    my $files = $this->callerPlugin->found_files;
+    my $map   = {};
+
+    foreach my $file (@$files) {
+        $map->{ $this->callerPlugin->base_filename( $file->name ) } = 1
+          if $this->callerPlugin->is_interesting_file($file);
+    }
+    return $map;
 }
 
 1;
@@ -65,7 +118,7 @@ Dist::Zilla::Plugin::LocalHTML::Pod2HTML - Pod::Simple::HTML wrapper to generate
 
 =head1 VERSION
 
-version v0.1.0
+version v0.1.1
 
 =head1 ATTRIBUTES
 
